#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .differential_viscosity_model import differential_viscosity_model as differential_viscosity_model_cls
from .swirl_dominated_flow import swirl_dominated_flow as swirl_dominated_flow_cls

class rng_options(Group):
    """
    'rng_options' child.
    """

    fluent_name = "rng-options"

    child_names = \
        ['differential_viscosity_model', 'swirl_dominated_flow']

    _child_classes = dict(
        differential_viscosity_model=differential_viscosity_model_cls,
        swirl_dominated_flow=swirl_dominated_flow_cls,
    )

    return_type = "<object object at 0x7f83499c9220>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .frequency_type import frequency_type as frequency_type_cls
from .save_frequency import save_frequency as save_frequency_cls

class save_data_file_every(Group):
    """
    Set the auto save frequency type to either time-step or crank-angle and set the corresponding frequency.
    """

    fluent_name = "save-data-file-every"

    child_names = \
        ['frequency_type', 'save_frequency']

    _child_classes = dict(
        frequency_type=frequency_type_cls,
        save_frequency=save_frequency_cls,
    )

    return_type = "<object object at 0x7fad5e816b00>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .file_partition_method import file_partition_method as file_partition_method_cls

class use_case_file_method(Command):
    """
    Enable the use-case-file method for auto partitioning.
    
    Parameters
    ----------
        file_partition_method : bool
            'file_partition_method' child.
    
    """

    fluent_name = "use-case-file-method"

    argument_names = \
        ['file_partition_method']

    _child_classes = dict(
        file_partition_method=file_partition_method_cls,
    )

    return_type = "<object object at 0x7fad5c8391f0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .design_points_1 import design_points as design_points_cls
from .current_design_point import current_design_point as current_design_point_cls

class parametric_studies_child(Group):
    """
    'child_object_type' of parametric_studies.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['design_points', 'current_design_point']

    _child_classes = dict(
        design_points=design_points_cls,
        current_design_point=current_design_point_cls,
    )

    return_type = "<object object at 0x7f0b2c1cfcd0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .report_type import report_type as report_type_cls
from .user_specified_origin_and_axis import user_specified_origin_and_axis as user_specified_origin_and_axis_cls
from .origin_1 import origin as origin_cls
from .axis_1 import axis as axis_cls
from .mass_criterion import mass_criterion as mass_criterion_cls
from .physics import physics as physics_cls
from .boundary_zones_names import boundary_zones_names as boundary_zones_names_cls
from .boundary_zones_1 import boundary_zones as boundary_zones_cls
from .retain_instantaneous_values import retain_instantaneous_values as retain_instantaneous_values_cls
from .inj_mass_rate_last_tstp import inj_mass_rate_last_tstp as inj_mass_rate_last_tstp_cls
from .inj_mass_rate_last_flow import inj_mass_rate_last_flow as inj_mass_rate_last_flow_cls
from .inj_mass_rate_prev_mass import inj_mass_rate_prev_mass as inj_mass_rate_prev_mass_cls
from .inj_mass_rate_prev_time import inj_mass_rate_prev_time as inj_mass_rate_prev_time_cls
from .show_unsteady_rate import show_unsteady_rate as show_unsteady_rate_cls
from .old_props import old_props as old_props_cls
from .average_over import average_over as average_over_cls
from .per_injection import per_injection as per_injection_cls
from .injection_list import injection_list as injection_list_cls

class injection_child(Group):
    """
    'child_object_type' of injection.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['report_type', 'user_specified_origin_and_axis', 'origin', 'axis',
         'mass_criterion', 'physics', 'boundary_zones_names',
         'boundary_zones', 'retain_instantaneous_values',
         'inj_mass_rate_last_tstp', 'inj_mass_rate_last_flow',
         'inj_mass_rate_prev_mass', 'inj_mass_rate_prev_time',
         'show_unsteady_rate', 'old_props', 'average_over', 'per_injection',
         'injection_list']

    _child_classes = dict(
        report_type=report_type_cls,
        user_specified_origin_and_axis=user_specified_origin_and_axis_cls,
        origin=origin_cls,
        axis=axis_cls,
        mass_criterion=mass_criterion_cls,
        physics=physics_cls,
        boundary_zones_names=boundary_zones_names_cls,
        boundary_zones=boundary_zones_cls,
        retain_instantaneous_values=retain_instantaneous_values_cls,
        inj_mass_rate_last_tstp=inj_mass_rate_last_tstp_cls,
        inj_mass_rate_last_flow=inj_mass_rate_last_flow_cls,
        inj_mass_rate_prev_mass=inj_mass_rate_prev_mass_cls,
        inj_mass_rate_prev_time=inj_mass_rate_prev_time_cls,
        show_unsteady_rate=show_unsteady_rate_cls,
        old_props=old_props_cls,
        average_over=average_over_cls,
        per_injection=per_injection_cls,
        injection_list=injection_list_cls,
    )

    return_type = "<object object at 0x7fad5c848f50>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .compute_node import compute_node as compute_node_cls

class show_connectivity(Command):
    """
    Show machine connectivity.
    
    Parameters
    ----------
        compute_node : int
            'compute_node' child.
    
    """

    fluent_name = "show-connectivity"

    argument_names = \
        ['compute_node']

    _child_classes = dict(
        compute_node=compute_node_cls,
    )

    return_type = "<object object at 0x7fad5c839c10>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple


class ni(Real, AllowedValuesMixin):
    fluent_name = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .flow_scheme import flow_scheme as flow_scheme_cls
from .coupled_form import coupled_form as coupled_form_cls
from .solve_n_phase import solve_n_phase as solve_n_phase_cls

class p_v_coupling(Group):
    """
    Select the pressure velocity coupling scheme.
    """

    fluent_name = "p-v-coupling"

    child_names = \
        ['flow_scheme', 'coupled_form', 'solve_n_phase']

    _child_classes = dict(
        flow_scheme=flow_scheme_cls,
        coupled_form=coupled_form_cls,
        solve_n_phase=solve_n_phase_cls,
    )

    return_type = "<object object at 0x7f0b2c4faeb0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .enable_turb_damping import enable_turb_damping as enable_turb_damping_cls
from .turb_damping_factor import turb_damping_factor as turb_damping_factor_cls

class turbulence_damping(Group):
    fluent_name = ...
    child_names = ...
    enable_turb_damping: enable_turb_damping_cls = ...
    turb_damping_factor: turb_damping_factor_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .x_axis_2 import x_axis as x_axis_cls
from .y_axis_2 import y_axis as y_axis_cls

class log_scale(Group):
    """
    'log_scale' child.
    """

    fluent_name = "log-scale"

    child_names = \
        ['x_axis', 'y_axis']

    _child_classes = dict(
        x_axis=x_axis_cls,
        y_axis=y_axis_cls,
    )

    return_type = "<object object at 0x7fad5c9405d0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .max_coarse_levels_2 import max_coarse_levels as max_coarse_levels_cls
from .coarsen_by_interval_2 import coarsen_by_interval as coarsen_by_interval_cls

class coarsening_parameters(Group):
    """
    'coarsening_parameters' child.
    """

    fluent_name = "coarsening-parameters"

    child_names = \
        ['max_coarse_levels', 'coarsen_by_interval']

    _child_classes = dict(
        max_coarse_levels=max_coarse_levels_cls,
        coarsen_by_interval=coarsen_by_interval_cls,
    )

    return_type = "<object object at 0x7f0b2c3f0a70>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .continuous_phase import continuous_phase as continuous_phase_cls
from .enable_rough_wall_treatment import enable_rough_wall_treatment as enable_rough_wall_treatment_cls
from .volume_displacement import volume_displacement as volume_displacement_cls

class interaction(Group):
    fluent_name = ...
    child_names = ...
    continuous_phase: continuous_phase_cls = ...
    enable_rough_wall_treatment: enable_rough_wall_treatment_cls = ...
    volume_displacement: volume_displacement_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .list import list as list_cls
from .list_properties import list_properties as list_properties_cls
from .duplicate import duplicate as duplicate_cls
from .mixture_child import mixture_child


class mixture(NamedObject[mixture_child], CreatableNamedObjectMixinOld[mixture_child]):
    """
    'mixture' child.
    """

    fluent_name = "mixture"

    command_names = \
        ['list', 'list_properties', 'duplicate']

    _child_classes = dict(
        list=list_cls,
        list_properties=list_properties_cls,
        duplicate=duplicate_cls,
    )

    child_object_type: mixture_child = mixture_child
    """
    child_object_type of mixture.
    """
    return_type = "<object object at 0x7f0b2d69bad0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .numbers import numbers as numbers_cls
from .rules import rules as rules_cls
from .log_scale_1 import log_scale as log_scale_cls
from .auto_scale_1 import auto_scale as auto_scale_cls
from .labels import labels as labels_cls

class axes(Group):
    """
    'axes' child.
    """

    fluent_name = "axes"

    child_names = \
        ['numbers', 'rules', 'log_scale', 'auto_scale', 'labels']

    _child_classes = dict(
        numbers=numbers_cls,
        rules=rules_cls,
        log_scale=log_scale_cls,
        auto_scale=auto_scale_cls,
        labels=labels_cls,
    )

    return_type = "<object object at 0x7f0b2c2e2b50>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)


class fixed_time_step_count(Integer):
    """
     Set Number of Fixed Time Steps.
    """

    fluent_name = "fixed-time-step-count"

    return_type = "<object object at 0x7f0b2c2e0400>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .report_name import report_name as report_name_cls
from .file_name_path import file_name_path as file_name_path_cls

class export_simulation_report_as_pdf(Command):
    """
    Export the provided simulation report as a PDF file.
    
    Parameters
    ----------
        report_name : str
            'report_name' child.
        file_name_path : str
            'file_name_path' child.
    
    """

    fluent_name = "export-simulation-report-as-pdf"

    argument_names = \
        ['report_name', 'file_name_path']

    _child_classes = dict(
        report_name=report_name_cls,
        file_name_path=file_name_path_cls,
    )

    return_type = "<object object at 0x7f0b2c1ce1a0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .all_1 import all as all_cls
from .one_to_one_pairing_1 import one_to_one_pairing as one_to_one_pairing_cls
from .new_interface_zones import new_interface_zones as new_interface_zones_cls
from .si_create import si_create as si_create_cls
from .si_name import si_name as si_name_cls
from .apply_mapped import apply_mapped as apply_mapped_cls
from .static_interface import static_interface as static_interface_cls

class auto_pairing(Command):
    """
    Automatically pair and create mesh interfaces for some or all interface zones.
    
    Parameters
    ----------
        all : bool
            'all' child.
        one_to_one_pairing : bool
            'one_to_one_pairing' child.
        new_interface_zones : List
            Select unintersected interface zones for pairing.
        si_create : bool
            'si_create' child.
        si_name : str
            Enter a prefix for mesh interface names.
        apply_mapped : bool
            Apply Mapped option at solids.
        static_interface : bool
            'static_interface' child.
    
    """

    fluent_name = "auto-pairing"

    argument_names = \
        ['all', 'one_to_one_pairing', 'new_interface_zones', 'si_create',
         'si_name', 'apply_mapped', 'static_interface']

    _child_classes = dict(
        all=all_cls,
        one_to_one_pairing=one_to_one_pairing_cls,
        new_interface_zones=new_interface_zones_cls,
        si_create=si_create_cls,
        si_name=si_name_cls,
        apply_mapped=apply_mapped_cls,
        static_interface=static_interface_cls,
    )

    return_type = "<object object at 0x7f78debc1fa0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .command_name import command_name as command_name_cls

class delete(CommandWithPositionalArgs):
    """
    Delete an execute-command.
    
    Parameters
    ----------
        command_name : str
            'command_name' child.
    
    """

    fluent_name = "delete"

    argument_names = \
        ['command_name']

    _child_classes = dict(
        command_name=command_name_cls,
    )

    return_type = "<object object at 0x7fad5c84a4b0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .option_1 import option as option_cls
from .create_particles_every_particle_step import create_particles_every_particle_step as create_particles_every_particle_step_cls
from .dpm_time_step import dpm_time_step as dpm_time_step_cls
from .n_time_steps import n_time_steps as n_time_steps_cls
from .clear_particles_from_domain import clear_particles_from_domain as clear_particles_from_domain_cls

class unsteady_tracking(Group):
    fluent_name = ...
    child_names = ...
    option: option_cls = ...
    create_particles_every_particle_step: create_particles_every_particle_step_cls = ...
    dpm_time_step: dpm_time_step_cls = ...
    n_time_steps: n_time_steps_cls = ...
    clear_particles_from_domain: clear_particles_from_domain_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .surface_list import surface_list as surface_list_cls
from .volume_list import volume_list as volume_list_cls
from .num_of_moments import num_of_moments as num_of_moments_cls
from .write_to_file import write_to_file as write_to_file_cls
from .filename import filename as filename_cls
from .overwrite import overwrite as overwrite_cls

class moments(Command):
    """
    Set moments for population balance.
    
    Parameters
    ----------
        surface_list : List
            'surface_list' child.
        volume_list : List
            'volume_list' child.
        num_of_moments : int
            'num_of_moments' child.
        write_to_file : bool
            'write_to_file' child.
        filename : str
            'filename' child.
        overwrite : bool
            'overwrite' child.
    
    """

    fluent_name = "moments"

    argument_names = \
        ['surface_list', 'volume_list', 'num_of_moments', 'write_to_file',
         'filename', 'overwrite']

    _child_classes = dict(
        surface_list=surface_list_cls,
        volume_list=volume_list_cls,
        num_of_moments=num_of_moments_cls,
        write_to_file=write_to_file_cls,
        filename=filename_cls,
        overwrite=overwrite_cls,
    )

    return_type = "<object object at 0x7fad5c838590>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .banded_coloring import banded_coloring as banded_coloring_cls
from .number_of_bands import number_of_bands as number_of_bands_cls

class coloring(Group):
    """
    Select coloring option.
    """

    fluent_name = "coloring"

    child_names = \
        ['banded_coloring', 'number_of_bands']

    _child_classes = dict(
        banded_coloring=banded_coloring_cls,
        number_of_bands=number_of_bands_cls,
    )

    return_type = "<object object at 0x7fad5c941cd0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .clip_to_range import clip_to_range as clip_to_range_cls
from .minimum_1 import minimum as minimum_cls
from .maximum_1 import maximum as maximum_cls

class auto_range_off(Group):
    """
    'auto_range_off' child.
    """

    fluent_name = "auto-range-off"

    child_names = \
        ['clip_to_range', 'minimum', 'maximum']

    _child_classes = dict(
        clip_to_range=clip_to_range_cls,
        minimum=minimum_cls,
        maximum=maximum_cls,
    )

    return_type = "<object object at 0x7fad5c84b380>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .phase_child import phase_child


class phase(NamedObject[phase_child], CreatableNamedObjectMixinOld[phase_child]):
    """
    'phase' child.
    """

    fluent_name = "phase"

    child_object_type: phase_child = phase_child
    """
    child_object_type of phase.
    """
    return_type = "<object object at 0x7f8340a01e40>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)


class sbes_update_interval_k_omega(Integer):
    """
    Set an integer value how often the k and omega equations are updated in a transient SBES run.
    """

    fluent_name = "sbes-update-interval-k-omega"

    return_type = "<object object at 0x7fad5e815520>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .thermal_bc import thermal_bc as thermal_bc_cls
from .temperature import temperature as temperature_cls
from .q import q as q_cls

class phase_child(Group):
    """
    'child_object_type' of phase.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['thermal_bc', 'temperature', 'q']

    _child_classes = dict(
        thermal_bc=thermal_bc_cls,
        temperature=temperature_cls,
        q=q_cls,
    )

    return_type = "<object object at 0x7f8327cc43a0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .name_1 import name as name_cls
from .title import title as title_cls
from .temporary import temporary as temporary_cls
from .graphics_objects import graphics_objects as graphics_objects_cls
from .display_state_name import display_state_name as display_state_name_cls
from .display_3 import display as display_cls

class scene_child(Group):
    """
    'child_object_type' of scene.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'title', 'temporary', 'graphics_objects',
         'display_state_name']

    command_names = \
        ['display']

    _child_classes = dict(
        name=name_cls,
        title=title_cls,
        temporary=temporary_cls,
        graphics_objects=graphics_objects_cls,
        display_state_name=display_state_name_cls,
        display=display_cls,
    )

    return_type = "<object object at 0x7f0b2c1cdf10>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .vof_smooth_options import vof_smooth_options as vof_smooth_options_cls
from .calculate_patch import calculate_patch as calculate_patch_cls

class patch(Group):
    """
    'patch' child.
    """

    fluent_name = "patch"

    child_names = \
        ['vof_smooth_options']

    command_names = \
        ['calculate_patch']

    _child_classes = dict(
        vof_smooth_options=vof_smooth_options_cls,
        calculate_patch=calculate_patch_cls,
    )

    return_type = "<object object at 0x7f0b2c3f3b10>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .gravity import gravity as gravity_cls
from .components import components as components_cls

class gravity(Group):
    """
    'gravity' child.
    """

    fluent_name = "gravity"

    child_names = \
        ['gravity', 'components']

    _child_classes = dict(
        gravity=gravity_cls,
        components=components_cls,
    )

    return_type = "<object object at 0x7f83499c8fd0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .visible import visible as visible_cls
from .size import size as size_cls
from .color import color as color_cls
from .log_scale import log_scale as log_scale_cls
from .format import format as format_cls
from .user_skip import user_skip as user_skip_cls
from .show_all import show_all as show_all_cls
from .position import position as position_cls
from .font_name import font_name as font_name_cls
from .font_automatic import font_automatic as font_automatic_cls
from .font_size import font_size as font_size_cls
from .length_1 import length as length_cls
from .width import width as width_cls
from .bground_transparent import bground_transparent as bground_transparent_cls
from .bground_color import bground_color as bground_color_cls
from .title_elements import title_elements as title_elements_cls

class color_map(Group):
    """
    'color_map' child.
    """

    fluent_name = "color-map"

    child_names = \
        ['visible', 'size', 'color', 'log_scale', 'format', 'user_skip',
         'show_all', 'position', 'font_name', 'font_automatic', 'font_size',
         'length', 'width', 'bground_transparent', 'bground_color',
         'title_elements']

    _child_classes = dict(
        visible=visible_cls,
        size=size_cls,
        color=color_cls,
        log_scale=log_scale_cls,
        format=format_cls,
        user_skip=user_skip_cls,
        show_all=show_all_cls,
        position=position_cls,
        font_name=font_name_cls,
        font_automatic=font_automatic_cls,
        font_size=font_size_cls,
        length=length_cls,
        width=width_cls,
        bground_transparent=bground_transparent_cls,
        bground_color=bground_color_cls,
        title_elements=title_elements_cls,
    )

    return_type = "<object object at 0x7f0b2c2e1c00>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .initial_time_steps import initial_time_steps as initial_time_steps_cls
from .initial_outer_iter import initial_outer_iter as initial_outer_iter_cls

class initial_outer_iterations(Group):
    fluent_name = ...
    child_names = ...
    initial_time_steps: initial_time_steps_cls = ...
    initial_outer_iter: initial_outer_iter_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .faces_1 import faces as faces_cls
from .edges_1 import edges as edges_cls
from .nodes_1 import nodes as nodes_cls
from .material_color import material_color as material_color_cls

class manual(Group):
    """
    'manual' child.
    """

    fluent_name = "manual"

    child_names = \
        ['faces', 'edges', 'nodes', 'material_color']

    _child_classes = dict(
        faces=faces_cls,
        edges=edges_cls,
        nodes=nodes_cls,
        material_color=material_color_cls,
    )

    return_type = "<object object at 0x7f832725b3e0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .blade_pitch_collective import blade_pitch_collective as blade_pitch_collective_cls
from .blade_pitch_cyclic_sin import blade_pitch_cyclic_sin as blade_pitch_cyclic_sin_cls
from .blade_pitch_cyclic_cos import blade_pitch_cyclic_cos as blade_pitch_cyclic_cos_cls

class blade_pitch_angles(Group):
    """
    Menu to define the rotor pitch and flapping angles.
    
     - blade-pitch-collective    : , 
     - blade-pitch-cyclic-sin    : , 
     - blade-pitch-cyclic-cos    : , 
    
    For more details please consult the help option of the corresponding menu or TUI command.
    """

    fluent_name = "blade-pitch-angles"

    child_names = \
        ['blade_pitch_collective', 'blade_pitch_cyclic_sin',
         'blade_pitch_cyclic_cos']

    _child_classes = dict(
        blade_pitch_collective=blade_pitch_collective_cls,
        blade_pitch_cyclic_sin=blade_pitch_cyclic_sin_cls,
        blade_pitch_cyclic_cos=blade_pitch_cyclic_cos_cls,
    )

    return_type = "<object object at 0x7f78df5da570>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .option_1 import option as option_cls
from .create_particles_every_particle_step import create_particles_every_particle_step as create_particles_every_particle_step_cls
from .dpm_time_step import dpm_time_step as dpm_time_step_cls
from .n_time_steps import n_time_steps as n_time_steps_cls
from .clear_particles_from_domain import clear_particles_from_domain as clear_particles_from_domain_cls

class unsteady_tracking(Group):
    """
    'unsteady_tracking' child.
    """

    fluent_name = "unsteady-tracking"

    child_names = \
        ['option', 'create_particles_every_particle_step', 'dpm_time_step',
         'n_time_steps', 'clear_particles_from_domain']

    _child_classes = dict(
        option=option_cls,
        create_particles_every_particle_step=create_particles_every_particle_step_cls,
        dpm_time_step=dpm_time_step_cls,
        n_time_steps=n_time_steps_cls,
        clear_particles_from_domain=clear_particles_from_domain_cls,
    )

    return_type = "<object object at 0x7fad5e817370>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .change_type import change_type as change_type_cls
from .velocity_inlet_child import velocity_inlet_child


class velocity_inlet(NamedObject[velocity_inlet_child], CreatableNamedObjectMixinOld[velocity_inlet_child]):
    """
    'velocity_inlet' child.
    """

    fluent_name = "velocity-inlet"

    command_names = \
        ['change_type']

    _child_classes = dict(
        change_type=change_type_cls,
    )

    child_object_type: velocity_inlet_child = velocity_inlet_child
    """
    child_object_type of velocity_inlet.
    """
    return_type = "<object object at 0x7f83276c48d0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .reset_statistics import reset_statistics as reset_statistics_cls
from .statistics_controls import statistics_controls as statistics_controls_cls

class statistics(Group):
    """
    Specify statistics parameter of sampling and averaging of flow and optical quantiies.
    """

    fluent_name = "statistics"

    child_names = \
        ['reset_statistics']

    command_names = \
        ['statistics_controls']

    _child_classes = dict(
        reset_statistics=reset_statistics_cls,
        statistics_controls=statistics_controls_cls,
    )

    return_type = "<object object at 0x7f0b2d206010>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .refine_mesh import refine_mesh as refine_mesh_cls
from .boundary_zones import boundary_zones as boundary_zones_cls
from .layer_count import layer_count as layer_count_cls
from .parameters import parameters as parameters_cls

class multi_layer_refinement(Group):
    """
    Enter the multiple boundary layer refinement menu.
    """

    fluent_name = "multi-layer-refinement"

    command_names = \
        ['refine_mesh', 'boundary_zones', 'layer_count', 'parameters']

    _child_classes = dict(
        refine_mesh=refine_mesh_cls,
        boundary_zones=boundary_zones_cls,
        layer_count=layer_count_cls,
        parameters=parameters_cls,
    )

    return_type = "<object object at 0x7fad5e817b10>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .fixed_periodic import fixed_periodic as fixed_periodic_cls
from .fixed_periodic_type import fixed_periodic_type as fixed_periodic_type_cls
from .fixed_periodic_type_value import fixed_periodic_type_value as fixed_periodic_type_value_cls
from .times_step_periods import times_step_periods as times_step_periods_cls
from .total_period_run import total_period_run as total_period_run_cls

class fixed_periodic(Group):
    fluent_name = ...
    child_names = ...
    fixed_periodic: fixed_periodic_cls = ...
    fixed_periodic_type: fixed_periodic_type_cls = ...
    fixed_periodic_type_value: fixed_periodic_type_value_cls = ...
    times_step_periods: times_step_periods_cls = ...
    total_period_run: total_period_run_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .draw_major_rules import draw_major_rules as draw_major_rules_cls
from .major_rule_weight import major_rule_weight as major_rule_weight_cls
from .major_rule_line_color import major_rule_line_color as major_rule_line_color_cls
from .draw_minor_rules import draw_minor_rules as draw_minor_rules_cls
from .minor_rule_weight import minor_rule_weight as minor_rule_weight_cls
from .minor_rule_line_color import minor_rule_line_color as minor_rule_line_color_cls

class x_axis(Group):
    """
    'x_axis' child.
    """

    fluent_name = "x-axis"

    child_names = \
        ['draw_major_rules', 'major_rule_weight', 'major_rule_line_color',
         'draw_minor_rules', 'minor_rule_weight', 'minor_rule_line_color']

    _child_classes = dict(
        draw_major_rules=draw_major_rules_cls,
        major_rule_weight=major_rule_weight_cls,
        major_rule_line_color=major_rule_line_color_cls,
        draw_minor_rules=draw_minor_rules_cls,
        minor_rule_weight=minor_rule_weight_cls,
        minor_rule_line_color=minor_rule_line_color_cls,
    )

    return_type = "<object object at 0x7f0b2c2e2960>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .size_by import size_by as size_by_cls
from .range import range as range_cls

class variable(Group):
    """
    'variable' child.
    """

    fluent_name = "variable"

    child_names = \
        ['size_by', 'range']

    _child_classes = dict(
        size_by=size_by_cls,
        range=range_cls,
    )

    return_type = "<object object at 0x7fad5c940c40>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .mesh_2 import mesh as mesh_cls
from .contour import contour as contour_cls
from .vector_1 import vector as vector_cls
from .pathline import pathline as pathline_cls
from .particle_track import particle_track as particle_track_cls
from .lic import lic as lic_cls
from .olic import olic as olic_cls
from .contours import contours as contours_cls
from .particle_tracks import particle_tracks as particle_tracks_cls
from .colors import colors as colors_cls
from .lights import lights as lights_cls
from .picture import picture as picture_cls
from .views import views as views_cls
from .windows import windows as windows_cls
from .raytracing_options import raytracing_options as raytracing_options_cls

class graphics(Group, _ChildNamedObjectAccessorMixin):
    """
    'graphics' child.
    """

    fluent_name = "graphics"

    child_names = \
        ['mesh', 'contour', 'vector', 'pathline', 'particle_track', 'lic',
         'olic', 'contours', 'particle_tracks', 'colors', 'lights', 'picture',
         'views', 'windows', 'raytracing_options']

    _child_classes = dict(
        mesh=mesh_cls,
        contour=contour_cls,
        vector=vector_cls,
        pathline=pathline_cls,
        particle_track=particle_track_cls,
        lic=lic_cls,
        olic=olic_cls,
        contours=contours_cls,
        particle_tracks=particle_tracks_cls,
        colors=colors_cls,
        lights=lights_cls,
        picture=picture_cls,
        views=views_cls,
        windows=windows_cls,
        raytracing_options=raytracing_options_cls,
    )

    return_type = "<object object at 0x7f0b2c1cd4e0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .mass_flow_1 import mass_flow as mass_flow_cls
from .heat_transfer import heat_transfer as heat_transfer_cls
from .heat_transfer_sensible import heat_transfer_sensible as heat_transfer_sensible_cls
from .rad_heat_trans import rad_heat_trans as rad_heat_trans_cls
from .film_mass_flow import film_mass_flow as film_mass_flow_cls
from .film_heat_transfer import film_heat_transfer as film_heat_transfer_cls
from .electric_current import electric_current as electric_current_cls
from .pressure_work_1 import pressure_work as pressure_work_cls
from .viscous_work import viscous_work as viscous_work_cls

class fluxes(Group):
    """
    'fluxes' child.
    """

    fluent_name = "fluxes"

    command_names = \
        ['mass_flow', 'heat_transfer', 'heat_transfer_sensible',
         'rad_heat_trans', 'film_mass_flow', 'film_heat_transfer',
         'electric_current', 'pressure_work', 'viscous_work']

    _child_classes = dict(
        mass_flow=mass_flow_cls,
        heat_transfer=heat_transfer_cls,
        heat_transfer_sensible=heat_transfer_sensible_cls,
        rad_heat_trans=rad_heat_trans_cls,
        film_mass_flow=film_mass_flow_cls,
        film_heat_transfer=film_heat_transfer_cls,
        electric_current=electric_current_cls,
        pressure_work=pressure_work_cls,
        viscous_work=viscous_work_cls,
    )

    return_type = "<object object at 0x7f0b2c1cee00>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .trim_option import trim_option as trim_option_cls
from .update_frequency import update_frequency as update_frequency_cls
from .damping_factor import damping_factor as damping_factor_cls
from .thrust_coefficient import thrust_coefficient as thrust_coefficient_cls
from .x_moment_coefficient import x_moment_coefficient as x_moment_coefficient_cls
from .y_moment_coefficient import y_moment_coefficient as y_moment_coefficient_cls

class trimming(Group):
    fluent_name = ...
    child_names = ...
    trim_option: trim_option_cls = ...
    update_frequency: update_frequency_cls = ...
    damping_factor: damping_factor_cls = ...
    thrust_coefficient: thrust_coefficient_cls = ...
    x_moment_coefficient: x_moment_coefficient_cls = ...
    y_moment_coefficient: y_moment_coefficient_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .mod_name import mod_name as mod_name_cls

class copy_modification(Command):
    """
    Copy a single case modification.
    
    Parameters
    ----------
        mod_name : str
            'mod_name' child.
    
    """

    fluent_name = "copy-modification"

    argument_names = \
        ['mod_name']

    _child_classes = dict(
        mod_name=mod_name_cls,
    )

    return_type = "<object object at 0x7fad5c84a790>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .pseudo_time_courant_number import pseudo_time_courant_number as pseudo_time_courant_number_cls
from .pseudo_time_step_method_solid_zone import pseudo_time_step_method_solid_zone as pseudo_time_step_method_solid_zone_cls
from .time_step_size_scale_factor import time_step_size_scale_factor as time_step_size_scale_factor_cls

class pseudo_time_method_local_time_step(Group):
    """
    'pseudo_time_method_local_time_step' child.
    """

    fluent_name = "pseudo-time-method-local-time-step"

    child_names = \
        ['pseudo_time_courant_number', 'pseudo_time_step_method_solid_zone',
         'time_step_size_scale_factor']

    _child_classes = dict(
        pseudo_time_courant_number=pseudo_time_courant_number_cls,
        pseudo_time_step_method_solid_zone=pseudo_time_step_method_solid_zone_cls,
        time_step_size_scale_factor=time_step_size_scale_factor_cls,
    )

    return_type = "<object object at 0x7f0b2c3f00a0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .a_1 import a as a_cls
from .b import b as b_cls
from .c import c as c_cls

class blottner_curve_fit(Group):
    fluent_name = ...
    child_names = ...
    a: a_cls = ...
    b: b_cls = ...
    c: c_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .include_pop_in_fsi_force import include_pop_in_fsi_force as include_pop_in_fsi_force_cls
from .steady_2way_fsi import steady_2way_fsi as steady_2way_fsi_cls
from .include_viscous_fsi_force import include_viscous_fsi_force as include_viscous_fsi_force_cls
from .explicit_fsi_force import explicit_fsi_force as explicit_fsi_force_cls
from .starting_t_re_initialization import starting_t_re_initialization as starting_t_re_initialization_cls

class expert(Group):
    fluent_name = ...
    child_names = ...
    include_pop_in_fsi_force: include_pop_in_fsi_force_cls = ...
    steady_2way_fsi: steady_2way_fsi_cls = ...
    include_viscous_fsi_force: include_viscous_fsi_force_cls = ...
    explicit_fsi_force: explicit_fsi_force_cls = ...
    starting_t_re_initialization: starting_t_re_initialization_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .enhanced_cell_relocation_method import enhanced_cell_relocation_method as enhanced_cell_relocation_method_cls
from .load_legacy_particles import load_legacy_particles as load_legacy_particles_cls
from .overset_relocation_robustness_level import overset_relocation_robustness_level as overset_relocation_robustness_level_cls
from .legacy_particle_location_method_enabled import legacy_particle_location_method_enabled as legacy_particle_location_method_enabled_cls

class particle_relocation(Group):
    fluent_name = ...
    child_names = ...
    enhanced_cell_relocation_method: enhanced_cell_relocation_method_cls = ...
    load_legacy_particles: load_legacy_particles_cls = ...
    overset_relocation_robustness_level: overset_relocation_robustness_level_cls = ...
    legacy_particle_location_method_enabled: legacy_particle_location_method_enabled_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .background import background as background_cls
from .color_by_type import color_by_type as color_by_type_cls
from .foreground import foreground as foreground_cls
from .by_type import by_type as by_type_cls
from .by_surface import by_surface as by_surface_cls
from .far_field_faces import far_field_faces as far_field_faces_cls
from .inlet_faces import inlet_faces as inlet_faces_cls
from .interior_faces import interior_faces as interior_faces_cls
from .internal_faces import internal_faces as internal_faces_cls
from .outlet_faces import outlet_faces as outlet_faces_cls
from .overset_faces import overset_faces as overset_faces_cls
from .periodic_faces import periodic_faces as periodic_faces_cls
from .rans_les_interface_faces import rans_les_interface_faces as rans_les_interface_faces_cls
from .symmetry_faces import symmetry_faces as symmetry_faces_cls
from .axis_faces import axis_faces as axis_faces_cls
from .free_surface_faces import free_surface_faces as free_surface_faces_cls
from .traction_faces import traction_faces as traction_faces_cls
from .wall_faces import wall_faces as wall_faces_cls
from .interface_faces import interface_faces as interface_faces_cls
from .surface_2 import surface as surface_cls
from .skip_label import skip_label as skip_label_cls
from .automatic_skip import automatic_skip as automatic_skip_cls
from .reset_colors import reset_colors as reset_colors_cls
from .list_colors import list_colors as list_colors_cls

class colors(Group):
    """
    'colors' child.
    """

    fluent_name = "colors"

    child_names = \
        ['background', 'color_by_type', 'foreground', 'by_type', 'by_surface',
         'far_field_faces', 'inlet_faces', 'interior_faces', 'internal_faces',
         'outlet_faces', 'overset_faces', 'periodic_faces',
         'rans_les_interface_faces', 'symmetry_faces', 'axis_faces',
         'free_surface_faces', 'traction_faces', 'wall_faces',
         'interface_faces', 'surface', 'skip_label', 'automatic_skip']

    command_names = \
        ['reset_colors', 'list_colors']

    _child_classes = dict(
        background=background_cls,
        color_by_type=color_by_type_cls,
        foreground=foreground_cls,
        by_type=by_type_cls,
        by_surface=by_surface_cls,
        far_field_faces=far_field_faces_cls,
        inlet_faces=inlet_faces_cls,
        interior_faces=interior_faces_cls,
        internal_faces=internal_faces_cls,
        outlet_faces=outlet_faces_cls,
        overset_faces=overset_faces_cls,
        periodic_faces=periodic_faces_cls,
        rans_les_interface_faces=rans_les_interface_faces_cls,
        symmetry_faces=symmetry_faces_cls,
        axis_faces=axis_faces_cls,
        free_surface_faces=free_surface_faces_cls,
        traction_faces=traction_faces_cls,
        wall_faces=wall_faces_cls,
        interface_faces=interface_faces_cls,
        surface=surface_cls,
        skip_label=skip_label_cls,
        automatic_skip=automatic_skip_cls,
        reset_colors=reset_colors_cls,
        list_colors=list_colors_cls,
    )

    return_type = "<object object at 0x7fad5c941fa0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .from_name import from_name as from_name_cls
from .new_name import new_name as new_name_cls

class copy(Command):
    """
    Copy graphics object.
    
    Parameters
    ----------
        from_name : str
            'from_name' child.
        new_name : str
            'new_name' child.
    
    """

    fluent_name = "copy"

    argument_names = \
        ['from_name', 'new_name']

    _child_classes = dict(
        from_name=from_name_cls,
        new_name=new_name_cls,
    )

    return_type = "<object object at 0x7f0b2c3f3ed0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .set_velocity_and_vof_cutoffs_child import set_velocity_and_vof_cutoffs_child


class set_velocity_and_vof_cutoffs(NamedObject[set_velocity_and_vof_cutoffs_child], CreatableNamedObjectMixinOld[set_velocity_and_vof_cutoffs_child]):
    """
    'set_velocity_and_vof_cutoffs' child.
    """

    fluent_name = "set-velocity-and-vof-cutoffs"

    child_object_type: set_velocity_and_vof_cutoffs_child = set_velocity_and_vof_cutoffs_child
    """
    child_object_type of set_velocity_and_vof_cutoffs.
    """
    return_type = "<object object at 0x7f83272598c0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .headlight_setting import headlight_setting as headlight_setting_cls
from .lights_on import lights_on as lights_on_cls
from .lighting_interpolation import lighting_interpolation as lighting_interpolation_cls
from .set_ambient_color import set_ambient_color as set_ambient_color_cls
from .set_light import set_light as set_light_cls

class lights(Group):
    fluent_name = ...
    child_names = ...
    headlight_setting: headlight_setting_cls = ...
    lights_on: lights_on_cls = ...
    lighting_interpolation: lighting_interpolation_cls = ...
    command_names = ...

    def set_ambient_color(self, rgb_vector: Tuple[float | str, float | str, float | str):
        """
        'set_ambient_color' command.
        
        Parameters
        ----------
            rgb_vector : Tuple
                'rgb_vector' child.
        
        """

    def set_light(self, light_number: int, light_on: bool, rgb_vector: Tuple[float | str, float | str, float | str, use_view_factor: bool, change_light_direction: bool, direction_vector: Tuple[float | str, float | str, float | str):
        """
        'set_light' command.
        
        Parameters
        ----------
            light_number : int
                'light_number' child.
            light_on : bool
                'light_on' child.
            rgb_vector : Tuple
                'rgb_vector' child.
            use_view_factor : bool
                'use_view_factor' child.
            change_light_direction : bool
                'change_light_direction' child.
            direction_vector : Tuple
                'direction_vector' child.
        
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .child_object_type_child import child_object_type_child


class pb_qmom(NamedObject[child_object_type_child], CreatableNamedObjectMixinOld[child_object_type_child]):
    """
    'pb_qmom' child.
    """

    fluent_name = "pb-qmom"

    child_object_type: child_object_type_child = child_object_type_child
    """
    child_object_type of pb_qmom.
    """
    return_type = "<object object at 0x7f83409e1bb0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .vof_min_seeding import vof_min_seeding as vof_min_seeding_cls
from .ia_grad_sym import ia_grad_sym as ia_grad_sym_cls

class area_density(Group):
    """
    Interfacial area density menu.
    """

    fluent_name = "area-density"

    child_names = \
        ['vof_min_seeding', 'ia_grad_sym']

    _child_classes = dict(
        vof_min_seeding=vof_min_seeding_cls,
        ia_grad_sym=ia_grad_sym_cls,
    )

    return_type = "<object object at 0x7f0b2c4fb560>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .display import display as display_cls
from .vector_child import vector_child


class vector(NamedObject[vector_child], CreatableNamedObjectMixinOld[vector_child]):
    """
    'vector' child.
    """

    fluent_name = "vector"

    command_names = \
        ['display']

    _child_classes = dict(
        display=display_cls,
    )

    child_object_type: vector_child = vector_child
    """
    child_object_type of vector.
    """
    return_type = "<object object at 0x7f832725b830>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .residual_smoothing_factor import residual_smoothing_factor as residual_smoothing_factor_cls
from .residual_smoothing_iteration import residual_smoothing_iteration as residual_smoothing_iteration_cls

class residual_smoothing(Group):
    """
    'residual_smoothing' child.
    """

    fluent_name = "residual-smoothing"

    child_names = \
        ['residual_smoothing_factor', 'residual_smoothing_iteration']

    _child_classes = dict(
        residual_smoothing_factor=residual_smoothing_factor_cls,
        residual_smoothing_iteration=residual_smoothing_iteration_cls,
    )

    return_type = "<object object at 0x7f8327259b90>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .patch_reconstructed_interface import patch_reconstructed_interface as patch_reconstructed_interface_cls
from .use_volumetric_smoothing import use_volumetric_smoothing as use_volumetric_smoothing_cls
from .smoothing_relaxation_factor import smoothing_relaxation_factor as smoothing_relaxation_factor_cls
from .execute_smoothing import execute_smoothing as execute_smoothing_cls

class vof_smooth_options(Group):
    fluent_name = ...
    child_names = ...
    patch_reconstructed_interface: patch_reconstructed_interface_cls = ...
    use_volumetric_smoothing: use_volumetric_smoothing_cls = ...
    smoothing_relaxation_factor: smoothing_relaxation_factor_cls = ...
    command_names = ...

    def execute_smoothing(self, ):
        """
        Execute volumetric smoothing for volume fraction.
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .report_files_child import report_files_child


class report_files(NamedObject[report_files_child], CreatableNamedObjectMixinOld[report_files_child]):
    """
    'report_files' child.
    """

    fluent_name = "report-files"

    child_object_type: report_files_child = report_files_child
    """
    child_object_type of report_files.
    """
    return_type = "<object object at 0x7fad5c8492c0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .pressure_velocity_coupling_controls import pressure_velocity_coupling_controls as pressure_velocity_coupling_controls_cls
from .pressure_velocity_coupling_method import pressure_velocity_coupling_method as pressure_velocity_coupling_method_cls
from .gradient_controls import gradient_controls as gradient_controls_cls
from .specify_gradient_method import specify_gradient_method as specify_gradient_method_cls

class methods(Group):
    fluent_name = ...
    child_names = ...
    pressure_velocity_coupling_controls: pressure_velocity_coupling_controls_cls = ...
    pressure_velocity_coupling_method: pressure_velocity_coupling_method_cls = ...
    gradient_controls: gradient_controls_cls = ...
    specify_gradient_method: specify_gradient_method_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .display import display as display_cls
from .particle_tracks_child import particle_tracks_child


class particle_tracks(NamedObject[particle_tracks_child], CreatableNamedObjectMixinOld[particle_tracks_child]):
    """
    'particle_tracks' child.
    """

    fluent_name = "particle-tracks"

    command_names = \
        ['display']

    _child_classes = dict(
        display=display_cls,
    )

    child_object_type: particle_tracks_child = particle_tracks_child
    """
    child_object_type of particle_tracks.
    """
    return_type = "<object object at 0x7f83271581a0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .axis_origin import axis_origin as axis_origin_cls
from .axis_direction import axis_direction as axis_direction_cls
from .radial_diffusivity import radial_diffusivity as radial_diffusivity_cls
from .tangential_diffusivity import tangential_diffusivity as tangential_diffusivity_cls
from .axial_diffusivity import axial_diffusivity as axial_diffusivity_cls

class cyl_orthotropic(Group):
    """
    'cyl_orthotropic' child.
    """

    fluent_name = "cyl-orthotropic"

    child_names = \
        ['axis_origin', 'axis_direction', 'radial_diffusivity',
         'tangential_diffusivity', 'axial_diffusivity']

    _child_classes = dict(
        axis_origin=axis_origin_cls,
        axis_direction=axis_direction_cls,
        radial_diffusivity=radial_diffusivity_cls,
        tangential_diffusivity=tangential_diffusivity_cls,
        axial_diffusivity=axial_diffusivity_cls,
    )

    return_type = "<object object at 0x7fad5d1960f0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .database import database as database_cls
from .fluid import fluid as fluid_cls
from .solid import solid as solid_cls
from .mixture import mixture as mixture_cls
from .inert_particle import inert_particle as inert_particle_cls
from .droplet_particle import droplet_particle as droplet_particle_cls
from .combusting_particle import combusting_particle as combusting_particle_cls
from .particle_mixture import particle_mixture as particle_mixture_cls
from .list_materials_1 import list_materials as list_materials_cls
from .list_properties_3 import list_properties as list_properties_cls

class materials(Group):
    fluent_name = ...
    child_names = ...
    database: database_cls = ...
    fluid: fluid_cls = ...
    solid: solid_cls = ...
    mixture: mixture_cls = ...
    inert_particle: inert_particle_cls = ...
    droplet_particle: droplet_particle_cls = ...
    combusting_particle: combusting_particle_cls = ...
    particle_mixture: particle_mixture_cls = ...
    command_names = ...

    def list_materials(self, ):
        """
        List all locally-stored materials.
        """

    def list_properties(self, name: str):
        """
        List the properties of a locally-stored material.
        
        Parameters
        ----------
            name : str
                'name' child.
        
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .execute_commands import execute_commands as execute_commands_cls
from .solution_animations import solution_animations as solution_animations_cls
from .case_modification_1 import case_modification as case_modification_cls
from .poor_mesh_numerics import poor_mesh_numerics as poor_mesh_numerics_cls

class calculation_activity(Group):
    """
    'calculation_activity' child.
    """

    fluent_name = "calculation-activity"

    child_names = \
        ['execute_commands', 'solution_animations', 'case_modification',
         'poor_mesh_numerics']

    _child_classes = dict(
        execute_commands=execute_commands_cls,
        solution_animations=solution_animations_cls,
        case_modification=case_modification_cls,
        poor_mesh_numerics=poor_mesh_numerics_cls,
    )

    return_type = "<object object at 0x7f78de9f8d00>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .change_type import change_type as change_type_cls
from .velocity_inlet_child import velocity_inlet_child


class velocity_inlet(NamedObject[velocity_inlet_child], CreatableNamedObjectMixinOld[velocity_inlet_child]):
    fluent_name = ...
    command_names = ...

    def change_type(self, zone_list: List[str], new_type: str):
        """
        'change_type' command.
        
        Parameters
        ----------
            zone_list : List
                'zone_list' child.
            new_type : str
                'new_type' child.
        
        """

    child_object_type: velocity_inlet_child = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .light_number import light_number as light_number_cls
from .light_on import light_on as light_on_cls
from .rgb_vector import rgb_vector as rgb_vector_cls
from .use_view_factor import use_view_factor as use_view_factor_cls
from .change_light_direction import change_light_direction as change_light_direction_cls
from .direction_vector_1 import direction_vector as direction_vector_cls

class set_light(Command):
    """
    'set_light' command.
    
    Parameters
    ----------
        light_number : int
            'light_number' child.
        light_on : bool
            'light_on' child.
        rgb_vector : List
            'rgb_vector' child.
        use_view_factor : bool
            'use_view_factor' child.
        change_light_direction : bool
            'change_light_direction' child.
        direction_vector : List
            'direction_vector' child.
    
    """

    fluent_name = "set-light"

    argument_names = \
        ['light_number', 'light_on', 'rgb_vector', 'use_view_factor',
         'change_light_direction', 'direction_vector']

    _child_classes = dict(
        light_number=light_number_cls,
        light_on=light_on_cls,
        rgb_vector=rgb_vector_cls,
        use_view_factor=use_view_factor_cls,
        change_light_direction=change_light_direction_cls,
        direction_vector=direction_vector_cls,
    )

    return_type = "<object object at 0x7f0b2c1cc820>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .application import application as application_cls
from .border_3 import border as border_cls
from .bottom_3 import bottom as bottom_cls
from .clear_3 import clear as clear_cls
from .company import company as company_cls
from .date import date as date_cls
from .left_3 import left as left_cls
from .right_4 import right as right_cls
from .top_3 import top as top_cls
from .visible_4 import visible as visible_cls
from .alignment import alignment as alignment_cls

class text(Group):
    """
    Enter the text window options menu.
    """

    fluent_name = "text"

    child_names = \
        ['application', 'border', 'bottom', 'clear', 'company', 'date',
         'left', 'right', 'top', 'visible', 'alignment']

    _child_classes = dict(
        application=application_cls,
        border=border_cls,
        bottom=bottom_cls,
        clear=clear_cls,
        company=company_cls,
        date=date_cls,
        left=left_cls,
        right=right_cls,
        top=top_cls,
        visible=visible_cls,
        alignment=alignment_cls,
    )

    return_type = "<object object at 0x7f0b2c1cd200>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .new import new as new_cls
from .open import open as open_cls
from .save import save as save_cls
from .save_as import save_as as save_as_cls
from .save_as_copy import save_as_copy as save_as_copy_cls
from .archive import archive as archive_cls

class parametric_project(Group):
    """
    'parametric_project' child.
    """

    fluent_name = "parametric-project"

    command_names = \
        ['new', 'open', 'save', 'save_as', 'save_as_copy', 'archive']

    _child_classes = dict(
        new=new_cls,
        open=open_cls,
        save=save_cls,
        save_as=save_as_cls,
        save_as_copy=save_as_copy_cls,
        archive=archive_cls,
    )

    return_type = "<object object at 0x7f83499c8f00>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .pressure_corr_grad import pressure_corr_grad as pressure_corr_grad_cls
from .face_pressure_calculation_method import face_pressure_calculation_method as face_pressure_calculation_method_cls
from .exclude_transient_term_in_face_pressure_calc import exclude_transient_term_in_face_pressure_calc as exclude_transient_term_in_face_pressure_calc_cls

class face_pressure_options(Group):
    fluent_name = ...
    child_names = ...
    pressure_corr_grad: pressure_corr_grad_cls = ...
    face_pressure_calculation_method: face_pressure_calculation_method_cls = ...
    exclude_transient_term_in_face_pressure_calc: exclude_transient_term_in_face_pressure_calc_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .list_simulation_reports import list_simulation_reports as list_simulation_reports_cls
from .generate_simulation_report import generate_simulation_report as generate_simulation_report_cls
from .view_simulation_report import view_simulation_report as view_simulation_report_cls
from .export_simulation_report_as_pdf import export_simulation_report_as_pdf as export_simulation_report_as_pdf_cls
from .export_simulation_report_as_html import export_simulation_report_as_html as export_simulation_report_as_html_cls
from .export_simulation_report_as_pptx import export_simulation_report_as_pptx as export_simulation_report_as_pptx_cls
from .write_simulation_report_names_to_file import write_simulation_report_names_to_file as write_simulation_report_names_to_file_cls
from .rename_simulation_report import rename_simulation_report as rename_simulation_report_cls
from .duplicate_simulation_report import duplicate_simulation_report as duplicate_simulation_report_cls
from .reset_report_to_defaults import reset_report_to_defaults as reset_report_to_defaults_cls
from .delete_simulation_report import delete_simulation_report as delete_simulation_report_cls
from .write_simulation_report_template_file import write_simulation_report_template_file as write_simulation_report_template_file_cls
from .read_simulation_report_template_file import read_simulation_report_template_file as read_simulation_report_template_file_cls

class simulation_reports(Group):
    """
    'simulation_reports' child.
    """

    fluent_name = "simulation-reports"

    command_names = \
        ['list_simulation_reports', 'generate_simulation_report',
         'view_simulation_report', 'export_simulation_report_as_pdf',
         'export_simulation_report_as_html',
         'export_simulation_report_as_pptx',
         'write_simulation_report_names_to_file', 'rename_simulation_report',
         'duplicate_simulation_report', 'reset_report_to_defaults',
         'delete_simulation_report', 'write_simulation_report_template_file',
         'read_simulation_report_template_file']

    _child_classes = dict(
        list_simulation_reports=list_simulation_reports_cls,
        generate_simulation_report=generate_simulation_report_cls,
        view_simulation_report=view_simulation_report_cls,
        export_simulation_report_as_pdf=export_simulation_report_as_pdf_cls,
        export_simulation_report_as_html=export_simulation_report_as_html_cls,
        export_simulation_report_as_pptx=export_simulation_report_as_pptx_cls,
        write_simulation_report_names_to_file=write_simulation_report_names_to_file_cls,
        rename_simulation_report=rename_simulation_report_cls,
        duplicate_simulation_report=duplicate_simulation_report_cls,
        reset_report_to_defaults=reset_report_to_defaults_cls,
        delete_simulation_report=delete_simulation_report_cls,
        write_simulation_report_template_file=write_simulation_report_template_file_cls,
        read_simulation_report_template_file=read_simulation_report_template_file_cls,
    )

    return_type = "<object object at 0x7f0b2c1ce300>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .max_fine_relaxations import max_fine_relaxations as max_fine_relaxations_cls
from .max_coarse_relaxations import max_coarse_relaxations as max_coarse_relaxations_cls

class flexible_cycle_parameters(Group):
    """
    'flexible_cycle_parameters' child.
    """

    fluent_name = "flexible-cycle-parameters"

    child_names = \
        ['max_fine_relaxations', 'max_coarse_relaxations']

    _child_classes = dict(
        max_fine_relaxations=max_fine_relaxations_cls,
        max_coarse_relaxations=max_coarse_relaxations_cls,
    )

    return_type = "<object object at 0x7f0b2c3f09e0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .faces import faces as faces_cls
from .list_properties_4 import list_properties as list_properties_cls

class bodies_child(Group):
    fluent_name = ...
    child_names = ...
    faces: faces_cls = ...
    command_names = ...

    def list_properties(self, ):
        """
        'list_properties' command.
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .diffusion_rate_constant import diffusion_rate_constant as diffusion_rate_constant_cls
from .pre_exponential_factor import pre_exponential_factor as pre_exponential_factor_cls
from .activation_energy import activation_energy as activation_energy_cls
from .char_porosity import char_porosity as char_porosity_cls
from .mean_pore_radius import mean_pore_radius as mean_pore_radius_cls
from .specific_internal_surface_area import specific_internal_surface_area as specific_internal_surface_area_cls
from .tortuosity import tortuosity as tortuosity_cls
from .burning_mode import burning_mode as burning_mode_cls

class intrinsic_model(Group):
    fluent_name = ...
    child_names = ...
    diffusion_rate_constant: diffusion_rate_constant_cls = ...
    pre_exponential_factor: pre_exponential_factor_cls = ...
    activation_energy: activation_energy_cls = ...
    char_porosity: char_porosity_cls = ...
    mean_pore_radius: mean_pore_radius_cls = ...
    specific_internal_surface_area: specific_internal_surface_area_cls = ...
    tortuosity: tortuosity_cls = ...
    burning_mode: burning_mode_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .direction_option import direction_option as direction_option_cls
from .vector import vector as vector_cls
from .point import point as point_cls
from .axis_label import axis_label as axis_label_cls

class axis_to(Group):
    """
    'axis_to' child.
    """

    fluent_name = "axis-to"

    child_names = \
        ['direction_option', 'vector', 'point', 'axis_label']

    _child_classes = dict(
        direction_option=direction_option_cls,
        vector=vector_cls,
        point=point_cls,
        axis_label=axis_label_cls,
    )

    return_type = "<object object at 0x7f0b2c4fad00>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .quality_1 import quality as quality_cls
from .denoiser import denoiser as denoiser_cls
from .thread_count import thread_count as thread_count_cls
from .max_rendering_timeout import max_rendering_timeout as max_rendering_timeout_cls

class rendering(Group):
    fluent_name = ...
    child_names = ...
    quality: quality_cls = ...
    denoiser: denoiser_cls = ...
    thread_count: thread_count_cls = ...
    max_rendering_timeout: max_rendering_timeout_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .number_of_blades import number_of_blades as number_of_blades_cls
from .tip_radius import tip_radius as tip_radius_cls
from .root_radius import root_radius as root_radius_cls
from .rotor_speed import rotor_speed as rotor_speed_cls

class basic_info(Group):
    """
    Menu to define the rotor basic informations:
    
     - Number of Blades 
     - Tip Radius 
     - Root Radius , 
     - Rotor Speed  , 
    
    For more details please consult the help option of the corresponding menu or TUI command.
    """

    fluent_name = "basic-info"

    child_names = \
        ['number_of_blades', 'tip_radius', 'root_radius', 'rotor_speed']

    _child_classes = dict(
        number_of_blades=number_of_blades_cls,
        tip_radius=tip_radius_cls,
        root_radius=root_radius_cls,
        rotor_speed=rotor_speed_cls,
    )

    return_type = "<object object at 0x7fad5e814f30>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .format_name import format_name as format_name_cls

class write_animation(Command):
    """
    Write animation sequence to the file.
    
    Parameters
    ----------
        format_name : str
            'format_name' child.
    
    """

    fluent_name = "write-animation"

    argument_names = \
        ['format_name']

    _child_classes = dict(
        format_name=format_name_cls,
    )

    return_type = "<object object at 0x7f0b2c1ce0c0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .fmg_courant_number import fmg_courant_number as fmg_courant_number_cls
from .enable_fmg_verbose import enable_fmg_verbose as enable_fmg_verbose_cls
from .customize_fmg_initialization import customize_fmg_initialization as customize_fmg_initialization_cls

class fmg_initialization(Group):
    fluent_name = ...
    child_names = ...
    fmg_courant_number: fmg_courant_number_cls = ...
    enable_fmg_verbose: enable_fmg_verbose_cls = ...
    command_names = ...

    def customize_fmg_initialization(self, multi_level_grid: int, residual_reduction_level: List[float | str], cycle_count: List[float | str]):
        """
        'customize_fmg_initialization' command.
        
        Parameters
        ----------
            multi_level_grid : int
                'multi_level_grid' child.
            residual_reduction_level : List
                'residual_reduction_level' child.
            cycle_count : List
                'cycle_count' child.
        
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .database_type import database_type as database_type_cls
from .copy_by_formula import copy_by_formula as copy_by_formula_cls
from .copy_by_name import copy_by_name as copy_by_name_cls
from .list_materials import list_materials as list_materials_cls
from .list_properties_2 import list_properties as list_properties_cls

class database(Group):
    """
    'database' child.
    """

    fluent_name = "database"

    child_names = \
        ['database_type']

    command_names = \
        ['copy_by_formula', 'copy_by_name', 'list_materials',
         'list_properties']

    _child_classes = dict(
        database_type=database_type_cls,
        copy_by_formula=copy_by_formula_cls,
        copy_by_name=copy_by_name_cls,
        list_materials=list_materials_cls,
        list_properties=list_properties_cls,
    )

    return_type = "<object object at 0x7f0b2d206290>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .type_1 import type as type_cls
from .method_1 import method as method_cls
from .specified_time_step import specified_time_step as specified_time_step_cls
from .incremental_time import incremental_time as incremental_time_cls
from .max_iter_per_time_step import max_iter_per_time_step as max_iter_per_time_step_cls
from .time_step_count_1 import time_step_count as time_step_count_cls
from .total_time_step_count import total_time_step_count as total_time_step_count_cls
from .total_time import total_time as total_time_cls
from .time_step_size import time_step_size as time_step_size_cls
from .solution_status import solution_status as solution_status_cls
from .extrapolate_vars import extrapolate_vars as extrapolate_vars_cls
from .max_flow_time import max_flow_time as max_flow_time_cls
from .control_time_step_size_variation import control_time_step_size_variation as control_time_step_size_variation_cls
from .use_average_cfl import use_average_cfl as use_average_cfl_cls
from .cfl_type import cfl_type as cfl_type_cls
from .cfl_based_time_stepping import cfl_based_time_stepping as cfl_based_time_stepping_cls
from .error_based_time_stepping import error_based_time_stepping as error_based_time_stepping_cls
from .undo_timestep import undo_timestep as undo_timestep_cls
from .predict_next import predict_next as predict_next_cls
from .rotating_mesh_flow_predictor import rotating_mesh_flow_predictor as rotating_mesh_flow_predictor_cls
from .mp_specific_time_stepping import mp_specific_time_stepping as mp_specific_time_stepping_cls
from .udf_hook import udf_hook as udf_hook_cls
from .fixed_periodic_1 import fixed_periodic as fixed_periodic_cls
from .duration_specification_method import duration_specification_method as duration_specification_method_cls
from .multiphase_specific_time_constraints import multiphase_specific_time_constraints as multiphase_specific_time_constraints_cls
from .solid_time_step_size import solid_time_step_size as solid_time_step_size_cls
from .time_step_size_for_acoustic_export import time_step_size_for_acoustic_export as time_step_size_for_acoustic_export_cls
from .extrapolate_eqn_vars import extrapolate_eqn_vars as extrapolate_eqn_vars_cls

class transient_controls(Group):
    """
    'transient_controls' child.
    """

    fluent_name = "transient-controls"

    child_names = \
        ['type', 'method', 'specified_time_step', 'incremental_time',
         'max_iter_per_time_step', 'time_step_count', 'total_time_step_count',
         'total_time', 'time_step_size', 'solution_status',
         'extrapolate_vars', 'max_flow_time',
         'control_time_step_size_variation', 'use_average_cfl', 'cfl_type',
         'cfl_based_time_stepping', 'error_based_time_stepping',
         'undo_timestep', 'predict_next', 'rotating_mesh_flow_predictor',
         'mp_specific_time_stepping', 'udf_hook', 'fixed_periodic',
         'duration_specification_method',
         'multiphase_specific_time_constraints', 'solid_time_step_size',
         'time_step_size_for_acoustic_export', 'extrapolate_eqn_vars']

    _child_classes = dict(
        type=type_cls,
        method=method_cls,
        specified_time_step=specified_time_step_cls,
        incremental_time=incremental_time_cls,
        max_iter_per_time_step=max_iter_per_time_step_cls,
        time_step_count=time_step_count_cls,
        total_time_step_count=total_time_step_count_cls,
        total_time=total_time_cls,
        time_step_size=time_step_size_cls,
        solution_status=solution_status_cls,
        extrapolate_vars=extrapolate_vars_cls,
        max_flow_time=max_flow_time_cls,
        control_time_step_size_variation=control_time_step_size_variation_cls,
        use_average_cfl=use_average_cfl_cls,
        cfl_type=cfl_type_cls,
        cfl_based_time_stepping=cfl_based_time_stepping_cls,
        error_based_time_stepping=error_based_time_stepping_cls,
        undo_timestep=undo_timestep_cls,
        predict_next=predict_next_cls,
        rotating_mesh_flow_predictor=rotating_mesh_flow_predictor_cls,
        mp_specific_time_stepping=mp_specific_time_stepping_cls,
        udf_hook=udf_hook_cls,
        fixed_periodic=fixed_periodic_cls,
        duration_specification_method=duration_specification_method_cls,
        multiphase_specific_time_constraints=multiphase_specific_time_constraints_cls,
        solid_time_step_size=solid_time_step_size_cls,
        time_step_size_for_acoustic_export=time_step_size_for_acoustic_export_cls,
        extrapolate_eqn_vars=extrapolate_eqn_vars_cls,
    )

    return_type = "<object object at 0x7fad5c84af50>"
